<?php
namespace Core\Facebook_livestream\Models;
use CodeIgniter\Model;
use GuzzleHttp\Client;

class Facebook_livestreamModel extends Model
{
    public function __construct(){
        $this->config = include realpath( __DIR__."/../Config.php" );
        include get_module_dir( __DIR__ , '../Facebook_profiles/Libraries/FacebookCookieApi.php');
        $app_id = get_option('facebook_client_id', '');
        $app_secret = get_option('facebook_client_secret', '');
        $app_version = get_option('facebook_app_version', 'v18.0');

        $group_permissions = get_option('facebook_group_permissions', 'publish_to_groups');
        if(stripos($group_permissions, "publish_video") === FALSE){
            update_option('facebook_group_permissions', $group_permissions.",publish_video");
        }

        $profile_permissions = get_option('facebook_profile_permissions', '');
        if(stripos($profile_permissions, "publish_video") === FALSE){
            update_option('facebook_profile_permissions', $profile_permissions?$profile_permissions.",publish_video":"publish_video");
        }

        try {
            $fb = new \JanuSoftware\Facebook\Facebook([
                'app_id' => $app_id,
                'app_secret' => $app_secret,
                'default_graph_version' => $app_version,
            ]);

            $this->fb = $fb;
        } catch (\Exception $e) {
            
        }

        //$this->ffmpeg = FCPATH."/ffmpeg/bin/ffmpeg.exe";
        //$this->ffprobe = FCPATH."/ffmpeg/bin/ffprobe.exe";
        $this->ffmpeg = "ffmpeg";
        $this->ffprobe = "ffprobe";
    }

    public function block_can_post(){
        return true;
    }

    public function block_plans(){
        return [
            "tab" => 10,
            "position" => 100,
            "permission" => true,
            "label" => __("Planning and Scheduling"),
            "items" => [
                [
                    "id" => $this->config['id'],
                    "name" => sprintf(__("%s scheduling & report"), $this->config['name']),
                ]
            ]
        ];
    }

    public function block_frame_livestreams($path = ""){
        $team_id = get_team("id");
        return [
            "position" => 100,
            "preview" => view( 'Core\Facebook_livestream\Views\preview', [ 'config' => $this->config ] ),
            "advance_options" => view( 'Core\Facebook_livestream\Views\advance_options', [ 'config' => $this->config ] ),
            "accounts" => db_fetch("*", TB_ACCOUNTS, ["social_network" => "facebook", "login_type" => 1, "status" => 1, "team_id" => $team_id])
        ];
    }

    public function livestream_validator($post){
        $errors = array();
        $data = json_decode( $post->data , 1);
        $medias = $data['medias'];

        if($post->social_network == 'facebook'){

            if($post->api_type == 1){
                if( is_image($medias[0]) ){
                    $errors[] = __("Facebook livestream only supports posting videos");
                }
            }

            if($post->api_type == 3){
                $errors[] = __("Currently, Facebook cookie method does not allow livestream");
            }
        }

        return $errors;
    }

    public function livestream_handler($post){
        $data = json_decode($post->data, false);
        $medias = $data->medias;
        $endpoint = "/".$post->account->pid."/";
        $shortlink_by = shortlink_by($data);

        $title = "";

        if( isset( $data->advance_options ) && isset( $data->advance_options->fb_title ) ){
            $title = $data->advance_options->fb_title;
        }

        
        $ffmpeg = "ffmpeg";
        $ffprobe = "ffprobe";
        $loop_file = TMPPATH().uniqid("livestream_").".txt";

        switch ($post->account->category) {
            case 'profile':
                $endpoint = "/me/live_videos";
                break;
            
            default:
                $endpoint = "/".$post->account->pid."/live_videos";
                break;
        }

        try
        {
            $caption = shortlink( spintax($data->caption), $shortlink_by );
            $link = shortlink( $data->link, $shortlink_by );
            $file_path = get_file_path($medias[0]);
            $watermark = livestream_watermark($file_path, $post->account);

            switch ($post->account->login_type) {
                case 1:
                    $params = [
                        "status" => "LIVE_NOW",
                        "privacy" => ["value" => "EVERYONE"],
                        "description" => $caption
                    ];

                    if($title != ""){
                        $params['title'] = $title;
                    }

                    //Create Live Video
                    $response = $this->fb->post($endpoint, $params, $post->account->token)->getDecodedBody();

                    $video_id = $response['id'];
                    $stream_url = $response['stream_url'];

                    if($params['status'] == "LIVE_NOW"){
                        $loop_times = 1;
                        if( isset( $data->advance_options ) && isset( $data->advance_options->loop ) ){
                            $loop_times = $data->advance_options->loop;
                        }

                        $loop = "";
                        for ($i=0; $i <= $loop_times; $i++) { 
                            $loop .= "file '".$file_path."'\n";
                        }
                        
                        @file_put_contents($loop_file, $loop);

                        $livestream_code = sprintf(
                            $this->ffmpeg.' -rtbufsize 256M -re -f concat -safe 0 -i "'.$loop_file.'" %s -c:a aac -ar 44100 -b:a 128k -pix_fmt yuv420p -profile:v baseline -bufsize 6000k -vb 4500k -maxrate 4500k -deinterlace -vcodec libx264 -preset veryfast -g 30 -r 30 -f flv "%s" > /dev/null & ',
                            $watermark,
                            $stream_url
                        );

                        @exec($livestream_code);

                        $attempts = 0;
                        do {
                            $attempts++;
                            sleep(2);
                            $response = $this->fb->get('/'.$video_id, $post->account->token)->getDecodedBody();
                            if($response['status'] != 'UNPUBLISHED') {
                                break;
                            }
                        } while($attempts <= 10);

                        @unlink($loop_file);

                        if($response['status'] != "UNPUBLISHED"){

                            preg_match('/src="([^"]+)"/', $response['embed_html'], $match);
                            $url = $match[1];
                            $url = explode("href=", $url);
                            $url = urldecode( $url[1] );
                            $url = str_replace("/&width=0", "", $url);
                            $url = explode("/&width", $url);
                            $url = $url[0];

                            $post_id = explode("/", $url);
                            $post_id = end($post_id);

                            return [
                                "status" => "success",
                                "message" => __('Success'),
                                "id" => $post_id,
                                "url" => $url,
                                "type" => $post->type
                            ];
                        }else{
                            return [
                                "status" => "error",
                                "message" => __( "Live stream unpublished, Please try again later" ),
                                "type" => $post->type
                            ];
                        }
                    }
                    break;

                    
                case 3: 
                    return [
                        "status" => "error",
                        "message" => __("Currently, Facebook cookie method does not allow livestream"),
                        "type" => $post->type
                    ];
                    break;
            }

        } catch(\Exception $e) {
            if($e->getCode() == 190){
                db_update(TB_ACCOUNTS, [ "status" => 0 ], [ "id" => $post->account->id ] );
            }
            unlink_watermark($medias);
            return [
                "status" => "error",
                "message" => __( $e->getMessage() ),
                "type" => $post->type
            ];
        }
    }
}
