<?php
namespace Core\Instagram_livestream\Models;
use CodeIgniter\Model;
use GuzzleHttp\Client;

class Instagram_livestreamModel extends Model
{
    public function __construct(){
        $this->config = include realpath( __DIR__."/../Config.php" );
        include get_module_dir( __DIR__ , '../Instagram_profiles/Libraries/Instagram_unofficial.php');
        $app_id = get_option('facebook_client_id', '');
        $app_secret = get_option('facebook_client_secret', '');
        $app_version = get_option('facebook_app_version', 'v18.0');

        try {
            $fb = new \JanuSoftware\Facebook\Facebook([
                'app_id' => $app_id,
                'app_secret' => $app_secret,
                'default_graph_version' => $app_version,
            ]);

            $this->fb = $fb;
        } catch (\Exception $e) {
            
        }

        //$this->ffmpeg = FCPATH."/ffmpeg/bin/ffmpeg.exe";
        //$this->ffprobe = FCPATH."/ffmpeg/bin/ffprobe.exe";
        $this->ffmpeg = "ffmpeg";
        $this->ffprobe = "ffprobe";
    }

    public function block_can_post(){
        return true;
    }

    public function block_plans(){
        return [
            "tab" => 10,
            "position" => 100,
            "permission" => true,
            "label" => __("Planning and Scheduling"),
            "items" => [
                [
                    "id" => $this->config['id'],
                    "name" => sprintf(__("%s scheduling & report"), $this->config['name']),
                ]
            ]
        ];
    }

    public function block_frame_livestreams($path = ""){
        $team_id = get_team("id");
        return [
            "position" => 100,
            "preview" => view( 'Core\Instagram_livestream\Views\preview', [ 'config' => $this->config ] ),
            "advance_options" => view( 'Core\Instagram_livestream\Views\advance_options', [ 'config' => $this->config ] ),
            "accounts" => db_fetch("*", TB_ACCOUNTS, ["social_network" => "instagram", "login_type" => 2, "status" => 1, "team_id" => $team_id])
        ];
    }

    public function livestream_validator($post){
        $errors = array();
        $data = json_decode( $post->data , 1);
        $medias = $data['medias'];

        if($post->social_network == 'instagram'){

            if($post->api_type == 1){
                $errors[] = __("Currently, Instagram official method does not allow livestream");
            }

            if($post->api_type == 2){
                if( is_image($medias[0]) ){
                    $errors[] = __("Instagram livestream only supports posting videos");
                }
            }
        }

        return $errors;
    }

    public function livestream_handler($post){
        $data = json_decode($post->data, false);
        $medias = $data->medias;
        $shortlink_by = shortlink_by($data);
        $loop_file = TMPPATH().uniqid("livestream_").".txt";
        $comment = "";

        if( isset( $data->advance_options ) && isset( $data->advance_options->ig_first_comment ) ){
            $comment = $data->advance_options->ig_first_comment;
        }

        try
        {
            $caption = shortlink( spintax($data->caption), $shortlink_by );
            $link = shortlink( $data->link, $shortlink_by );
            $file_path = get_file_path($medias[0]);
            $watermark = livestream_watermark($file_path, $post->account);

            switch ($post->account->login_type) {
                case 1:
                    return [
                        "status" => "error",
                        "message" => __("Currently, Instagram official method does not allow livestream"),
                        "type" => $post->type
                    ];
                    break;

                    
                case 2: 
                    if( isset( $data->advance_options ) && isset( $data->advance_options->ig_post_type ) ){
                        $post_type = $data->advance_options->ig_post_type;
                    }

                    if( $post->account->token == "" ){
                        db_update(TB_ACCOUNTS, [ "status" => 0 ], [ "id" => $post->account->id ] );
                        return [
                            "status" => "error",
                            "message" => __( "You have not authorized your Instagram account yet. Please re-login and try again" ),
                            "type" => $post->type
                        ];
                    }

                    $accessToken = json_decode($post->account->token);

                    if( !is_array($accessToken) && (!isset($accessToken->ig_username) || !isset($accessToken->ig_password)) ){
                        db_update(TB_ACCOUNTS, [ "status" => 0 ], [ "id" => $post->account->id ] );
                        return [
                            "status" => "error",
                            "message" => __( "You have not authorized your Instagram account yet. Please re-login and try again" ),
                            "type" => $post->type
                        ];
                    }

                    $ig_username = $accessToken->ig_username;
                    $ig_password = encrypt_decode($accessToken->ig_password);

                    $proxy = get_proxy($post->account->proxy);
                    $ig_auth = new \Instagram_unofficial($ig_username, $ig_password, $post->team_id, $proxy);
                    $createLive = $ig_auth->createLive();

                    if(!empty($createLive) && isset($createLive['broadcast_id'])){
                        $startLive = $ig_auth->startLive($createLive['broadcast_id']);

                        if($startLive['status'] == "ok"){
                            $stream_url = $createLive['upload_url'];
                            $loop_times = 1;
                            if( isset( $data->advance_options ) && isset( $data->advance_options->loop ) ){
                                $loop_times = $data->advance_options->loop;
                            }

                            $loop = "";
                            for ($i=0; $i <= $loop_times; $i++) { 
                                $loop .= "file '".$file_path."'\n";
                            }
                            
                            @file_put_contents($loop_file, $loop);

                            $livestream_code = sprintf(
                                $this->ffmpeg.' -rtbufsize 256M -re -f concat -safe 0 -i "'.$loop_file.'" %s -c:a aac -ar 44100 -b:a 128k -pix_fmt yuv420p -profile:v baseline -bufsize 6000k -vb 4500k -maxrate 4500k -deinterlace -vcodec libx264 -preset veryfast -g 30 -r 30 -f flv "%s" > /dev/null & ',
                                $watermark,
                                $stream_url
                            );

                            @exec($livestream_code);

                            if($comment != ""){
                                $commentLive = $ig_auth->commentLive($createLive['broadcast_id'],  $comment);
                                if(!empty($commentLive) && isset($commentLive['status']) && $commentLive['status'] == 'ok'){
                                    $ig_auth->pinComment($createLive['broadcast_id'], $commentLive['comment']['pk']);
                                }
                            }

                            return [
                                "status" => "success",
                                "message" => __('Success'),
                                "id" => $createLive['broadcast_id'],
                                "url" => "https://www.instagram.com/".$post->account->username."/live/",
                                "type" => $post->type
                            ];
                        }else{
                            return [
                                "status" => "error",
                                "message" => __( "Live stream unpublished, Please try again later" ),
                                "type" => $post->type
                            ];
                        }
                    }else{
                        return [
                            "status" => "error",
                            "message" => __( "Live stream unpublished, Please try again later" ),
                            "type" => $post->type
                        ];
                    }
                    break;
            }

        } catch(\Exception $e) {
            if($e->getCode() == 190){
                db_update(TB_ACCOUNTS, [ "status" => 0 ], [ "id" => $post->account->id ] );
            }
            unlink_watermark($medias);
            return [
                "status" => "error",
                "message" => __( $e->getMessage() ),
                "type" => $post->type
            ];
        }
    }
}
