<?php
namespace Core\Youtube_livestream\Models;
use CodeIgniter\Model;
use GuzzleHttp\Client;

class Youtube_livestreamModel extends Model
{
    public function __construct(){
        $this->config = include realpath( __DIR__."/../Config.php" );

        $client_id = get_option('youtube_client_id', '');
        $client_secret = get_option('youtube_api_secret', '');
        $api_key = get_option('youtube_api_key', '');

        $this->client = new \Google\Client();
        $this->client->setAccessType("offline");
        $this->client->setApprovalPrompt("force");
        $this->client->setApplicationName("Youtube");
        $this->client->setClientId( $client_id );
        $this->client->setClientSecret( $client_secret );
        $this->client->setRedirectUri(get_module_url());
        $this->client->setDeveloperKey( $api_key );
        $this->client->setScopes(
            [
                'https://www.googleapis.com/auth/youtube', 
                'https://www.googleapis.com/auth/userinfo.email'
            ]
        );

        $this->youtube = new \Google_Service_YouTube($this->client);
        $this->live_broadcast_snippet = new \Google_Service_YouTube_LiveBroadcastSnippet;
        $this->live_broadcast_status = new \Google_Service_YouTube_LiveBroadcastStatus;
        $this->live_broadcast = new \Google_Service_YouTube_LiveBroadcast;
        $this->live_stream_snippet = new \Google_Service_YouTube_LiveStreamSnippet;
        $this->cdn_settings = new \Google_Service_YouTube_CdnSettings;
        $this->live_stream = new \Google_Service_YouTube_LiveStream;

        $this->ffmpeg = "ffmpeg";
        $this->ffprobe = "ffprobe";

        //$this->ffmpeg = FCPATH."/ffmpeg/bin/ffmpeg.exe";
        //$this->ffprobe = FCPATH."/ffmpeg/bin/ffprobe.exe";
    }

    public function block_can_post(){
        return true;
    }

    public function block_plans(){
        return [
            "tab" => 10,
            "position" => 100,
            "permission" => true,
            "label" => __("Planning and Scheduling"),
            "items" => [
                [
                    "id" => $this->config['id'],
                    "name" => sprintf(__("%s scheduling & report"), $this->config['name']),
                ]
            ]
        ];
    }

    public function block_frame_livestreams($path = ""){
        $team_id = get_team("id");
        return [
            "position" => 100,
            "preview" => view( 'Core\Youtube_livestream\Views\preview', [ 'config' => $this->config ] ),
            "advance_options" => view( 'Core\Youtube_livestream\Views\advance_options', [ 'config' => $this->config ] ),
            "accounts" => db_fetch("*", TB_ACCOUNTS, ["social_network" => "youtube", "login_type" => 1, "status" => 1, "team_id" => $team_id])
        ];
    }

    public function livestream_validator($post){
        $errors = array();
        $data = json_decode( $post->data , 1);
        $medias = $data['medias'];

        if($post->social_network == 'youtube'){

            if($post->api_type == 1){
                if( is_image($medias[0]) ){
                    $errors[] = __("YouTube livestream only supports posting videos");
                }
            }
        }

        return $errors;
    }

    public function livestream_handler($post){
        $data = json_decode($post->data, false);
        $medias = $data->medias;
        $endpoint = "/".$post->account->pid."/";
        $shortlink_by = shortlink_by($data);
        $loop_file = TMPPATH().uniqid("livestream_").".txt";
        $file_path = get_file_path($medias[0]);
        $videoInfo = self::videoInfo($file_path);

        $title = "";

        if( isset( $data->advance_options ) && isset( $data->advance_options->youtube_title ) ){
            $title = $data->advance_options->youtube_title;
        }

        $tags = "";

        if( isset( $data->advance_options ) && isset( $data->advance_options->youtube_tags ) ){
            $tags = $data->advance_options->youtube_tags;
        }

        try
        {
            $this->client->setAccessToken($post->account->token);

            $caption = shortlink( spintax($data->caption), $shortlink_by );
            $link = shortlink( $data->link, $shortlink_by );
            $file_path = get_file_path($medias[0]);
            $watermark = livestream_watermark($file_path, $post->account);

            switch ($post->account->login_type) {
                case 1:
                    /** 
                     * Create an object for the liveBroadcast resource [specify snippet's title, scheduled start time, and scheduled end time]
                     */
                    $startdt = gmdate("Y-m-d\TH:i:s\Z", $post->time_post);
                    $this->live_broadcast_snippet->setTitle($title);
                    $this->live_broadcast_snippet->setDescription($caption);
                    $this->live_broadcast_snippet->setScheduledStartTime($startdt);

                    /**
                     * object for the liveBroadcast resource's status ["private, public or unlisted"]
                     */
                    $this->live_broadcast_status->setPrivacyStatus("public");

                    /** 
                     * API Request [inserts the liveBroadcast resource]
                     */
                    $this->live_broadcast->setSnippet($this->live_broadcast_snippet);
                    $this->live_broadcast->setStatus($this->live_broadcast_status);
                    $this->live_broadcast->setKind('youtube#liveBroadcast');

                    /**
                     * Execute Insert LiveBroadcast Resource Api [return an object that contains information about the new broadcast]
                     */
                    $broadcastsResponse = $this->youtube->liveBroadcasts->insert('snippet,status', $this->live_broadcast, array());
                    $response['broadcast_response'] = $broadcastsResponse;
                    $youtube_event_id = $broadcastsResponse['id'];

                    /**
                     * Call the API's videos.list method to retrieve the video resource.
                     */
                    $listResponse = $this->youtube->videos->listVideos("snippet", array('id' => $youtube_event_id));
                    $video = $listResponse[0]; 

                    /**
                     * update the tags and language via video resource
                     */
                    $videoSnippet = $video['snippet'];
                    if( isset( $data->advance_options ) && isset( $data->advance_options->youtube_title ) && (int)$data->advance_options->youtube_category != 0){
                        $videoSnippet->categoryId = (int)$data->advance_options->youtube_category;
                    }

                    
                    $videoSnippet->description = $caption;
                    if($tags != ""){
                        $videoSnippet->tags = $tags;   
                    }

                    $video['snippet'] = $videoSnippet;


                    /** 
                     * Update video resource [videos.update() method.]
                     */
                    $updateResponse = $this->youtube->videos->update("snippet", $video);
                    $response['video_response'] = $updateResponse;

                    /**
                     * object of livestream resource [snippet][title]
                     */
                    $this->live_stream_snippet->setTitle($title);

                    /**
                     * object for content distribution  [stream's format,ingestion type.]
                     */
                    $this->cdn_settings->setFormat($videoInfo->format);
                    $this->cdn_settings->setIngestionType('rtmp');
                    $this->cdn_settings->setResolution('1080p');
                    $this->cdn_settings->setFrameRate('30fps');
                    $this->cdn_settings->setIngestionType('rtmp');
                    $response['video_info'] = $videoInfo;

                    /** 
                     * API request [inserts liveStream resource.]
                     */
                    $this->live_stream->setSnippet($this->live_stream_snippet);
                    $this->live_stream->setCdn($this->cdn_settings);
                    $this->live_stream->setKind('youtube#liveStream');

                    /*
                     * execute the insert request [return an object that contains information about new stream]
                     */
                    $streamsResponse = $this->youtube->liveStreams->insert('snippet,cdn', $this->live_stream, array());
                    $response['stream_response'] = $streamsResponse;

                    /**
                     * Bind the broadcast to the live stream
                     */
                    $bindBroadcastResponse = $this->youtube->liveBroadcasts->bind(
                        $broadcastsResponse['id'],'id,contentDetails',
                        array(
                            'streamId' => $streamsResponse['id'],
                        ));
                    $response['bind_broadcast_response'] = $bindBroadcastResponse;

                    $broadcast_id = $broadcastsResponse['id'];
                    $stream_name = $streamsResponse->getCdn()->getIngestionInfo()->getStreamName();
                    $stream_url = $streamsResponse->getCdn()->getIngestionInfo()->getIngestionAddress();
                    $stream_url = $stream_url."/".$stream_name;

                    /*
                    * Create watermark
                    */
                    $watermark = livestream_watermark($file_path, $post->account);

                    /**************************/
                    /*  PROCCESS LIVE STREAM  */
                    /**************************/
                    $stream_url = preg_replace(
                        '#^rtmps://([^/]+?):443/#ui',
                        'rtmp://\1:80/',
                        $stream_url
                    );

                    //START LIVE
                    $loop_times = 1;
                    if( isset( $data->advance_options ) && isset( $data->advance_options->loop ) ){
                        $loop_times = $data->advance_options->loop;
                    }

                    $loop = "";
                    for ($i=0; $i <= $loop_times; $i++) { 
                        $loop .= "file '".$file_path."'\n";
                    }

                    file_put_contents($loop_file, $loop);

                    $livestream_code = sprintf(
                        $this->ffmpeg.' -rtbufsize 256M -re -f concat -safe 0 -i "'.$loop_file.'" %s -acodec libmp3lame -ar 44100 -b:a 128k -pix_fmt yuv420p -profile:v baseline -bufsize 6000k -vb 4500k -maxrate 4500k -deinterlace -vcodec libx264 -preset veryfast -g 30 -r 30 -f flv "%s" > /dev/null &', 
                        $watermark,
                        $stream_url
                    );

                    @exec($livestream_code);
                    //END START LIVE

                    $attempts = 0;
                    do {
                        $attempts++;
                        sleep(3);
                        try {
                            $transitionTesting = self::transitionEvent($broadcast_id, 'testing');
                        } catch (\Exception $e) {
                            $transitionTesting = self::transitionEvent($broadcast_id, 'testing');
                        }
                        if(!is_string($transitionTesting)){
                            break;
                        }
                    } while($attempts <= 20);

                    if(is_string($transitionTesting)){
                        $error = json_decode($transitionTesting, true);
                        return [
                            "status" => "error",
                            "message" => __( $error['error']['errors'][0]['message'] ),
                            "type" => $post_type
                        ];
                    }

                    $attempts = 0;
                    do {
                        $attempts++;
                        sleep(3);
                        try {
                            $transitionLive = self::transitionEvent($broadcast_id, 'live');
                        } catch (\Exception $e) {
                            $transitionLive = self::transitionEvent($broadcast_id, 'live');
                        }
                        if(!is_string($transitionLive)){
                            break;
                        }
                    } while($attempts <= 20);

                    if(is_string($transitionLive)){
                        $error = json_decode($transitionLive, true);
                        return [
                            "status" => "error",
                            "message" => __( $error['error']['errors'][0]['message'] ),
                            "type" => $post->type
                        ];
                    }

                    @unlink($loop_file);

                    $video_id = $response['broadcast_response']->getId();

                    return [
                        "status" => "success",
                        "message" => __('Success'),
                        "id" => $video_id,
                        "url" => "https://www.youtube.com/watch?v=".$video_id,
                        "type" => $post->type
                    ];
                    break;

                    
                case 3: 
                    return [
                        "status" => "error",
                        "message" => __("Currently, Facebook cookie method does not allow livestream"),
                        "type" => $post->type
                    ];
                    break;
            }

        } catch(\Exception $e) {
            pr($e,1);
            if($e->getCode() == 190){
                db_update(TB_ACCOUNTS, [ "status" => 0 ], [ "id" => $post->account->id ] );
            }
            unlink_watermark($medias);
            return [
                "status" => "error",
                "message" => __( $e->getMessage() ),
                "type" => $post->type
            ];
        }
    }

    public function transitionEvent($youtube_event_id, $broadcastStatus)
    {
        try{
            $part = "status, id, snippet";
            $liveBroadcasts = $this->youtube->liveBroadcasts;
            $transition = $liveBroadcasts->transition($broadcastStatus, $youtube_event_id, $part);

            return $transition;
        } catch(\Google_Exception $e ) {
            return $e->getMessage();
        } catch(\Exception $e){
            return $e->getMessage();
        }
    }

    public function videoInfo($videoPath = ""){
        exec($this->ffprobe.' -show_streams -i "'.$videoPath.'"', $output, $statusCode);
        $format = "240p";
        $result = array();

        if($statusCode == 0 && !empty($output)){


            $result = array();
            foreach ($output as $value) {
                
                $parse_value = explode("=", $value);
                if(count($parse_value) == 2){
                    $key = $parse_value[0];
                    $val = $parse_value[1];

                    $result[$key] = $val;
                }
            }

            $result = (object)$result;

            if(!empty($result)){

                $w = $result->width;
                $h = $result->height;

                if($w >= 1920 && $h >= 1080){
                    $format = "1080p";
                }elseif ($w >= 1280 && $h >= 720) {
                    $format = "720p";
                }elseif ($w >= 854 && $h >= 480) {
                    $format = "480p";
                }elseif ($w >= 640 && $h >= 360) {
                    $format = "360p";
                }elseif ($w >= 426 && $h >= 240) {
                    $format = "240p";
                }
            }

            $result->format = $format;
        }

        return $result;

    }

}
